==> nui_auth-0.0.29.tar.gz: lib/domain/nui_user_info.dart <==
import 'dart:convert';

import 'package:nui_core/data/nui_ent.dart';
import 'package:nui_core/string/nui_string_util.dart';
import 'package:nui_geolocator/nui_geolocator.dart';
import 'package:crypto/crypto.dart';

class AuthEmailAcc{
  AuthEmailAcc({this.email, this.password});
  String email;
  AuthPassword password;
}

class AuthPassword{
  AuthPassword(String realPassword){
    _realPassword = realPassword;
  }

  String _realPassword;

  String getRealPassword(String password){
    if(!match(maskedPassword, password)) return password;
    return _realPassword;
  }

  String get maskedPassword {
    var bytes1 = utf8.encode(_realPassword);         // data being hashed
    var hashed = sha256.convert(bytes1);
    return hashed.toString();
  }
}

class NUIUserInfo extends NUIEnt<NUIUserInfo>{
  NUIUserInfo.empty();
  NUIUserInfo({
    this.gender,
    this.dateOfBirth,
    this.latitude,
    this.longitude,
    this.areaCode,
    this.others
  });

  int userId;
  String gender; //Male, Female, other string
  String dateOfBirth; //yyyy-mm-dd
  double latitude;
  double longitude;
  AreaCode areaCode;
  Map<String, dynamic> others; //For other information

  @override
  NUIEntMapper<NUIUserInfo> mapper() => NUIUserInfoEnt();
}

class NUIUserInfoEnt extends NUIEntMapper<NUIUserInfo>{
  @override
  String entityName() => "NUIUserInfo";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIUserInfo>(name: "userId", type: NUIEntType.INTEGER, setter: (data, value) => data.userId = value, getter: (data) => data.userId),
      NUIEntField<NUIUserInfo>(name: "gender", type: NUIEntType.STRING, setter: (data, value) => data.gender = value, getter: (data) => data.gender),
      NUIEntField<NUIUserInfo>(name: "dateOfBirth", type: NUIEntType.STRING, setter: (data, value) => data.dateOfBirth = value, getter: (data) => data.dateOfBirth),
      NUIEntField<NUIUserInfo>(name: "latitude", type: NUIEntType.DOUBLE, setter: (data, value) => data.latitude = value, getter: (data) => data.latitude),
      NUIEntField<NUIUserInfo>(name: "longitude", type: NUIEntType.DOUBLE, setter: (data, value) => data.longitude = value, getter: (data) => data.longitude),
      NUIEntField<NUIUserInfo>(name: "areaCode", type: NUIEntType.OBJECT, setter: (data, value) => data.areaCode = asObject<AreaCode>(AreaCodeEntity(), value), getter: (data) => data.areaCode),
      NUIEntField<NUIUserInfo>(name: "others", type: NUIEntType.OBJECT, setter: (data, value) => data.others = asMap(value), getter: (data) => data.others),
    ];
  }

  @override
  NUIUserInfo newInstance() => NUIUserInfo.empty();
}

==> nui_auth-0.0.44.tar.gz: lib/domain/nui_user_info.dart <==
import 'dart:convert';

import 'package:nui_core/data/nui_ent.dart';
import 'package:nui_core/string/nui_string_util.dart';
import 'package:nui_geolocator/nui_geolocator.dart';
import 'package:crypto/crypto.dart';

class AuthEmailAcc{
  AuthEmailAcc({this.email, this.password});
  String email;
  AuthPassword password;
}

class AuthPassword{
  AuthPassword(String realPassword){
    _realPassword = realPassword;

    var bytes1 = utf8.encode(_realPassword);         // data being hashed
    var hashed = sha256.convert(bytes1);
    _maskedPassword = hashed.toString().substring(0, 10) + "A#1a";
  }

  String _realPassword;
  String _maskedPassword;

  String getRealPassword(String password){
    if(!match(maskedPassword, password)) return password;
    return _realPassword;
  }

  String get maskedPassword => _maskedPassword;
}

class NUIUserInfo extends NUIEnt<NUIUserInfo>{
  NUIUserInfo.empty();
  NUIUserInfo({
    this.gender,
    this.dateOfBirth,
    this.latitude,
    this.longitude,
    this.areaCode,
    this.others
  });

  int userId;
  String gender; //Male, Female, other string
  String dateOfBirth; //yyyy-mm-dd
  double latitude;
  double longitude;
  AreaCode areaCode;
  Map<String, dynamic> others; //For other information

  @override
  NUIEntMapper<NUIUserInfo> mapper() => NUIUserInfoEnt();
}

class NUIUserInfoEnt extends NUIEntMapper<NUIUserInfo>{
  @override
  String entityName() => "NUIUserInfo";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIUserInfo>(name: "userId", type: NUIEntType.INTEGER, setter: (data, value) => data.userId = value, getter: (data) => data.userId),
      NUIEntField<NUIUserInfo>(name: "gender", type: NUIEntType.STRING, setter: (data, value) => data.gender = value, getter: (data) => data.gender),
      NUIEntField<NUIUserInfo>(name: "dateOfBirth", type: NUIEntType.STRING, setter: (data, value) => data.dateOfBirth = value, getter: (data) => data.dateOfBirth),
      NUIEntField<NUIUserInfo>(name: "latitude", type: NUIEntType.DOUBLE, setter: (data, value) => data.latitude = value, getter: (data) => data.latitude),
      NUIEntField<NUIUserInfo>(name: "longitude", type: NUIEntType.DOUBLE, setter: (data, value) => data.longitude = value, getter: (data) => data.longitude),
      NUIEntField<NUIUserInfo>(name: "areaCode", type: NUIEntType.OBJECT, setter: (data, value) => data.areaCode = asObject<AreaCode>(AreaCodeEntity(), value), getter: (data) => data.areaCode),
      NUIEntField<NUIUserInfo>(name: "others", type: NUIEntType.OBJECT, setter: (data, value) => data.others = asMap(value), getter: (data) => data.others),
    ];
  }

  @override
  NUIUserInfo newInstance() => NUIUserInfo.empty();
}
